@@ -60,14 +60,14 @@ def BubbleSort(arr, reverse=False):
     ''' Returns the Sorted array
         Sorts an array using 'Bubble Sort' Algorithm
         Time Complexity :-
-            Best Case : Ω(N)            
+            Best Case : Ω(N)
             Worst Case : O(N²)
             Avg Case : Θ(N²)
         Space Complexity :-
             Worst Case : O(1)
     '''
     length = len(arr)
-    
+
     for i in range(length) :
         for j in range(length-i-1) :
             if arr[j] > arr[j+1] :
@@ -82,7 +82,7 @@ def BucketSort(arr, reverse=False):
     ''' Returns the Sorted array
         Sorts an array using 'Bucket Sort' Algorithm
         Time Complexity :-
-            Best Case : Ω(N+K)           
+            Best Case : Ω(N+K)
             Worst Case : O(N²)
             Avg Case : Θ(N+K)
         Space Complexity :-
@@ -118,14 +118,14 @@ def CocktailSort(arr, reverse=False):
     ''' Returns the Sorted array
         Sorts an array using 'Cocktail Sort' Algorithm
         Time Complexity :-
-            Best Case : Ω(N)            
+            Best Case : Ω(N)
             Worst Case : O(N²)
             Avg Case : Θ(N²)
         Space Complexity :-
             Worst Case : O(1)
     '''
 
-    def swap(i, j) : 
+    def swap(i, j) :
         arr[i], arr[j] = arr[j], arr[i]
 
     upper, lower, no_swap = len(arr)-1, 0, False
@@ -157,7 +157,7 @@ def CombSort(arr, reverse = False):
     ''' Returns the Sorted array
         Sorts an array using 'Comb Sort' Algorithm
         Time Complexity :-
-            Best Case : Ω(N*log(N))            
+            Best Case : Ω(N*log(N))
             Worst Case : O(N²)
             Avg Case : Θ(N²/2ᵖ) p => No. of Increments
         Space Complexity :-
@@ -192,7 +192,7 @@ def CountingSort(arr, reverse=False):
     ''' Returns the Sorted array
         Sorts an array using 'Counting Sort' Algorithm
         Time Complexity :-
-            Best Case : Ω(N+K)            
+            Best Case : Ω(N+K)
             Worst Case : O(N+K)
             Avg Case : Θ(N+K)
         Space Complexity :-
@@ -226,7 +226,7 @@ def CycleSort(arr, reverse=False):
     ''' Returns the Sorted array
         Sorts an array using 'Cycle Sort' Algorithm
         Time Complexity :-
-            Best Case : Ω(N²)            
+            Best Case : Ω(N²)
             Worst Case : O(N²)
             Avg Case : Θ(N²)
         Space Complexity :-
@@ -234,36 +234,36 @@ def CycleSort(arr, reverse=False):
     '''
 
     writes = 0
-   
+
     for cycleStart in range(0, len(arr)-1):
         item, pos = arr[cycleStart], cycleStart
 
         for i in range(cycleStart+1, len(arr)):
             if arr[i] < item:
                 pos += 1
-     
+
         if pos == cycleStart:
            continue
-     
+
         while item == arr[pos]:
            pos += 1
 
         arr[pos], item = item, arr[pos]
         writes += 1
-         
+
         while pos != cycleStart:
            pos = cycleStart
 
            for i in range(cycleStart+1, len(arr)):
              if arr[i] < item:
                pos += 1
-           
+
            while item == arr[pos]:
              pos += 1
 
            arr[pos], item = item, arr[pos]
            writes += 1
-   
+
     if reverse:
         return arr[::-1]
     else:
@@ -369,11 +369,12 @@ def InsertionSort(arr, reverse=False) :
 
 # Function to check if an array is Sorted
 def IsSorted(arr):
-    """ Returns True if the array is Sorted in either ascending or descending order;
-        False If Not
+    """ Returns 'asc' if the array is Sorted in ascending,
+        Returns 'desc' if the array is Sorted in descending;
+        Returns False if the array is in some random order.
     """
-    
-    ascend, descend = True, False
+
+    ascend, descend = None, None
 
     for i in range(len(arr)-1):
         if (arr[i] < arr[i+1]) and not descend:
@@ -383,7 +384,10 @@ def IsSorted(arr):
         else:
             return False
     else:
-        return True
+        if ascend:
+            return "asc"
+        elif descend:
+            return "desc"
 
 # Merge Sort
 def MergeSort(arr, reverse=False):
@@ -489,7 +493,7 @@ def QuickSort(arr, start, end, reverse=False):
 
             while (i <= j and arr[j] >= pivot):
                 j -= 1
-     
+
             if i <= j:
                 arr[i], arr[j] = arr[j], arr[i]
             else:
@@ -533,7 +537,7 @@ def RadixSort(arr, base=10, reverse=False):
         c[0] -= 1
 
         for i in range(1, largest+1):
-            c[i] += c[i-1] 
+            c[i] += c[i-1]
 
         result = [None]*len(arr)
 
@@ -642,7 +646,7 @@ def StrandSort(arr, reverse=False):
         out += b
 
         return out
-     
+
     def strand(arr):
         i, s = 0, [arr.pop(0)]
 
@@ -684,7 +688,7 @@ def TimSort(arr, reverse=False):
             n >>= 1
 
         return n+r
-     
+
     def insertionSort(arr, left, right):
         for i in range(left+1, right+1):
             j = i
@@ -702,24 +706,24 @@ def TimSort(arr, reverse=False):
 
         for i in range(0, len2):
             right.append(arr[m+i+1])
-     
+
         i, j, k = 0, 0, l
-         
+
         while i < len1 and j < len2:
             if left[i] <= right[j]:
                 arr[k] = left[i]
-                i += 1 
+                i += 1
             else:
                 arr[k] = right[j]
                 j += 1
-     
+
             k += 1
-     
+
         while i < len1:
             arr[k] = left[i]
             k += 1
             i += 1
-     
+
         while j < len2:
             arr[k] = right[j]
             k += 1
@@ -727,11 +731,11 @@ def TimSort(arr, reverse=False):
 
     n = len(arr)
     minRun = calcMinRun(n)
-     
+
     for start in range(0, n, minRun):
         end = min(start+minRun-1, n-1)
         insertionSort(arr, start, end)
- 
+
     size = minRun
 
     while size < n:
@@ -741,7 +745,7 @@ def TimSort(arr, reverse=False):
 
             if mid < right:
                 merge(arr, left, mid, right)
- 
+
         size = 2*size
 
     if reverse:
